@@ -17,7 +17,7 @@ import inspect
 import json
 import os
 import platform
-from pylxd import exceptions as lxd_exceptions
+from pylxd.deprecated import exceptions as lxd_exceptions
 
 import ddt
 import mock
@@ -33,10 +33,10 @@ from nova import test
 from nova.virt import fake
 from nova.virt import hardware
 
-from nova_lxd.nova.virt.lxd import container_ops
 from nova_lxd.nova.virt.lxd import driver
 from nova_lxd.nova.virt.lxd import host
-from nova_lxd.nova.virt.lxd.session import session
+from nova_lxd.nova.virt.lxd import operations as container_ops
+from nova_lxd.nova.virt.lxd import session
 from nova_lxd.nova.virt.lxd import utils as container_dir
 from nova_lxd.tests import stubs
 
@@ -47,8 +47,7 @@ class LXDTestConfig(test.NoDBTestCase):
         self.assertIsInstance(driver.CONF.lxd, cfg.ConfigOpts.GroupAttr)
         self.assertEqual(os.path.abspath('/var/lib/lxd'),
                          os.path.abspath(driver.CONF.lxd.root_dir))
-        self.assertEqual(5, driver.CONF.lxd.timeout)
-        self.assertEqual('nova-lxd-profile', driver.CONF.lxd.default_profile)
+        self.assertEqual(-1, driver.CONF.lxd.timeout)
 
 
 @ddt.ddt
@@ -87,13 +86,8 @@ class LXDTestDriver(test.NoDBTestCase):
             True,
             self.connection.init_host(None)
         )
-        self.ml.profile_create.assert_called_once_with(
-            {'name': 'fake_profile'})
 
     @stubs.annotated_data(
-        ('profile_fail', {'profile_list.side_effect': (lxd_exceptions.
-                                                       APIError('Fake',
-                                                                500))}),
         ('no_ping', {'host_ping.return_value': False}),
         ('ping_fail', {'host_ping.side_effect': (lxd_exceptions.
                                                  APIError('Fake',
@@ -108,11 +102,16 @@ class LXDTestDriver(test.NoDBTestCase):
         )
 
     @stubs.annotated_data(
-        ('running', 200, power_state.RUNNING),
-        ('shutdown', 102, power_state.SHUTDOWN),
-        ('crashed', 108, power_state.CRASHED),
-        ('suspend', 109, power_state.SUSPENDED),
-        ('no_state', 401, power_state.NOSTATE),
+        ('running', {'state': 200, 'mem': 0, 'max_mem': 0},
+         power_state.RUNNING),
+        ('shutdown', {'state': 102, 'mem': 0, 'max_mem': 0},
+         power_state.SHUTDOWN),
+        ('crashed', {'state': 108, 'mem': 0, 'max_mem': 0},
+         power_state.CRASHED),
+        ('suspend', {'state': 109, 'mem': 0, 'max_mem': 0},
+         power_state.SUSPENDED),
+        ('no_state', {'state': 401, 'mem': 0, 'max_mem': 0},
+         power_state.NOSTATE),
     )
     def test_get_info(self, tag, side_effect, expected):
         instance = stubs._fake_instance()
@@ -179,7 +178,7 @@ class LXDTestDriver(test.NoDBTestCase):
 
         with test.nested(
                 mock.patch.object(self.connection.container_ops,
-                                  'create_container'),
+                                  'spawn'),
         ) as (
                 create_container
         ):
@@ -201,7 +200,7 @@ class LXDTestDriver(test.NoDBTestCase):
                               'container_stop'),
             mock.patch.object(self.connection, 'cleanup'),
             mock.patch.object(container_ops.LXDContainerOperations,
-                              '_unplug_vifs'),
+                              'unplug_vifs'),
 
         ) as (
             container_destroy,
@@ -223,7 +222,7 @@ class LXDTestDriver(test.NoDBTestCase):
                 mock.patch.object(self.connection,
                                   'cleanup'),
                 mock.patch.object(container_ops.LXDContainerOperations,
-                                  '_unplug_vifs'),
+                                  'unplug_vifs'),
         ) as (
                 container_stop,
                 container_destroy,
@@ -234,8 +233,7 @@ class LXDTestDriver(test.NoDBTestCase):
             self.assertTrue(container_stop)
             self.assertTrue(container_destroy)
             self.assertTrue(cleanup)
-            unplug_vifs.assert_called_with(instance, network_info,
-                                           True)
+            unplug_vifs.assert_called_with(instance, network_info)
 
     @mock.patch('os.path.exists', mock.Mock(return_value=True))
     @mock.patch('shutil.rmtree')
@@ -276,51 +274,6 @@ class LXDTestDriver(test.NoDBTestCase):
         mi.return_value = return_value
         self.assertEqual('1.2.3.4', self.connection.get_host_ip_addr())
 
-    def test_rescue(self):
-        context = mock.Mock()
-        instance = stubs.MockInstance()
-        image_meta = mock.Mock()
-        network_info = mock.Mock()
-        self.ml.container_defined.return_value = True
-        with test.nested(
-                mock.patch.object(session.LXDAPISession,
-                                  'container_stop'),
-                mock.patch.object(self.connection.container_ops,
-                                  '_container_local_copy'),
-                mock.patch.object(session.LXDAPISession,
-                                  'container_destroy'),
-                mock.patch.object(self.connection.container_ops,
-                                  'spawn')
-
-        ) as (
-                container_stop,
-                container_local_copy,
-                container_destroy,
-                spawn
-        ):
-            self.connection.rescue(context, instance, network_info,
-                                   image_meta, 'secret')
-            self.assertTrue(container_stop)
-            self.assertTrue(container_local_copy)
-            self.assertTrue(container_destroy)
-            self.assertTrue(spawn)
-
-    def test_container_unrescue(self):
-        instance = stubs.MockInstance()
-        network_info = mock.Mock()
-        with test.nested(
-                mock.patch.object(session.LXDAPISession,
-                                  'container_move'),
-                mock.patch.object(session.LXDAPISession,
-                                  'container_destroy')
-        ) as (
-                container_move,
-                container_destroy
-        ):
-            self.connection.unrescue(instance, network_info)
-            self.assertTrue(container_move)
-            self.assertTrue(container_destroy)
-
     @mock.patch('socket.gethostname', mock.Mock(return_value='fake_hostname'))
     @mock.patch('os.statvfs', return_value=mock.Mock(f_blocks=131072000,
                                                      f_bsize=8192,
@@ -350,14 +303,21 @@ class LXDTestDriver(test.NoDBTestCase):
         ]
         value = self.connection.get_available_resource(None)
         value['cpu_info'] = json.loads(value['cpu_info'])
-        value['supported_instances'] = json.loads(value['supported_instances'])
-        expected = {'cpu_info': {'arch': platform.uname()[5],
-                                 'features': 'fake flag goes here',
-                                 'model': 'Fake CPU',
-                                 'topology': {'cores': '5',
-                                              'sockets': '10',
-                                              'threads': '4'},
-                                 'vendor': 'FakeVendor'},
+        value['supported_instances'] = [[arch.I686, hv_type.LXD,
+                                         vm_mode.EXE],
+                                        [arch.X86_64, hv_type.LXD,
+                                         vm_mode.EXE],
+                                        [arch.I686, hv_type.LXC,
+                                         vm_mode.EXE],
+                                        [arch.X86_64, hv_type.LXC,
+                                         vm_mode.EXE]]
+        expected = {'cpu_info': {u'arch': platform.uname()[5],
+                                 u'features': u'fake flag goes here',
+                                 u'model': u'Fake CPU',
+                                 u'topology': {u'cores': u'5',
+                                               u'sockets': u'10',
+                                               u'threads': u'4'},
+                                 u'vendor': u'FakeVendor'},
                     'hypervisor_hostname': 'fake_hostname',
                     'hypervisor_type': 'lxd',
                     'hypervisor_version': '011',
@@ -478,7 +438,6 @@ class LXDTestDriverNoops(test.NoDBTestCase):
         'get_all_volume_usage',
         'attach_volume',
         'detach_volume',
-        'finish_revert_migration',
         'soft_delete',
         'post_live_migration_at_source',
         'check_instance_shared_storage_local',
@@ -510,7 +469,6 @@ class LXDTestDriverNoops(test.NoDBTestCase):
 
     @ddt.data(
         'post_interrupted_snapshot_cleanup',
-        'post_live_migration',
         'check_instance_shared_storage_cleanup',
         'manage_image_cache',
     )
